Sgtin96Decoder class

Decodes SGTIN-96 EPC hex strings into EAN-13 barcodes.

SGTIN-96 is a 96-bit (24 hex char) encoding. See GS1 EPC Tag Data Standard for the full bit layout specification.

Constructors

Sgtin96Decoder()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(String epcHex) String?
Decodes a SGTIN-96 EPC hex string to EAN-13. Returns null if the EPC is not a valid SGTIN-96.