Rfid class
Constructors
- Rfid()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
onTagsRead
→ Stream<
List< UHFTag> > -
Stream of scanned tags, emitting a list of UHFTag on each read cycle.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
connect(
) → Future< bool> - Powers on the RFID Module.
-
disconnect(
) → Future< bool> - Powers off the RFID Module.
-
getPlatformVersion(
) → Future< String?> - Returns the Android version string.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setPower(
int readPower, int writePower) → Future< void> - Sets antenna power for read and write operations.
-
startScan(
) → Future< bool> - Starts reading tags.
-
stopScan(
) → Future< bool> - Stops reading tags.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited