UHFTag class

Represents a UHF RFID tag read from the scanner.

Constructors

UHFTag({required String epc, required int rssi, required int readCount, String? tid})
UHFTag.fromMap(dynamic map)
factory

Properties

ean String?
EAN-13 barcode decoded from SGTIN-96 EPC, or null if EPC is not SGTIN-96.
latefinal
epc String
final
hashCode int
The hash code for this object.
no setterinherited
readCount int
final
rssi int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tid String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited